@@ -1,10 +1,10 @@
-
-
 import re
 
-from pytest_httpserver import HTTPServer, URIPattern
 import requests
 
+from pytest_httpserver import HTTPServer
+from pytest_httpserver import URIPattern
+
 
 class PrefixMatch(URIPattern):
     def __init__(self, prefix: str):
